/*
 *  lverepair.c
 *
 *  Copyright (C) Gerhard Monzel - October 2003
 *
 *  This file is part of lve, a linux mpeg video editor
 *      
 *  lve tools are free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *   
 *  lve is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *   
 *  You should have received a copy of the GNU General Public License
 *  along with GNU Make; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */
#include <stdio.h>
#include "decoder.h"

static uint8_t buf[1024*256];

int main(int argc, char **argv)
{
  int     p, dmy;
  
  int     len;
  
  uint8_t seq_buf[512];
  int     seq_len = 0;
  
  int     locked  = 1;
    
  if ( (argc == 3) && !strcmp(argv[1],"-i") )
  {
    T_MPEG_DEC  decoder;
    T_FRAME_SRV *fs;
 
    if ( (fs = decoder.open(argv[2], &dmy)) != 0 ) 
    {
      for (p=0; p<fs->nFrames(); p++)
      {
        decoder.readFrame(fs, p, buf, &len, 0);

        if (fs->isGOP(p) && (seq_len>0) )
        {
          fprintf(stderr, ".");
          fwrite(seq_buf, seq_len, 1, stdout);
        }
        else if (fs->isSequence(p))
        {
          locked = 0;
          if ( (seq_len = T_FRAME_SRV::findStartCode(buf, len, GROUP_START_CODE)) > 0 )
          {
            buf[8]   = 0xFF;
            buf[9]   = 0xFF;
            buf[10] |= 0xC0;
            memcpy(seq_buf, buf, seq_len);
              
            fprintf(stderr, "\nnew SH, len = (%d)\n", seq_len);
            fprintf(stderr, "inserts: ");
          }
        }
        if (!locked) fwrite(buf, len, 1, stdout);
      }
      
      fprintf(stderr, "\ndone !\n");
      decoder.close(fs);
    }
  }
  else
    fprintf(stderr,"usage: lverepair -i <mpeg-file>\n");
}

